/**
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of ADC demo for the
 *          TOSHIBA 'TMPM380' Device Series
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */


/* this demo is to show ADC function with software trigger on M380-SK board       */
/* the variable voltage on VR1 is displayed on the 7seg LEDs with "x.xx V" format */

#include "tmpm380_adc.h"
#include "led.h"

ADC_Result result = { 0U };

WorkState adcState = BUSY;
uint32_t myResult = 0U;

uint32_t delay = 0U;
uint32_t adjustLight = 1000U;

void DisplayLED(uint32_t dat);

int main()
{
    /* 1. set ADC clock */
    ADC_SetClk(ADC_HOLD_FIX, ADC_FC_DIVIDE_LEVEL_NONE);

    /* 2. select trigger and AD channel, this time we use sofeware trigger, */
    /*    the VR1 is connected to AIN0, remember to input with macro TRG_ENABLE() */
    ADC_SetSWTrg(ADC_REG0, TRG_ENABLE(ADC_AIN0));

    /* 3. to let ADC module work, we must disable low power mode */
    ADC_SetLowPowerMode(DISABLE);

    /* 4. enable ADC module */
    ADC_Enable();

    /* 5. now start ADC */
    ADC_Start(ADC_TRG_SW);

    /* initialize LEDs on M380-SK board before display something */
    LEDInit();

    while (1U) {
        /* check ADC module state */
        adcState = ADC_GetConvertState(ADC_TRG_SW);

        if (adcState == DONE) {
            /* read ADC result when it is finished */
            result = ADC_GetConvertResult(ADC_REG0);

            /* get the real ADC result without other information */
            myResult = result.Bit.ADResult;

            /* software trigger, need to trig it again */
            ADC_Start(ADC_TRG_SW);
        }

        delay++;
        if (delay >= adjustLight) {
            delay = 0U;
            DisplayLED(myResult);
        } else {
            /* do nothing */
        }
    }
}



/* display AD value as real voltage with "x.xx V" format */
#define FULL_MV 4751U            /* mV unit for full scale, change it depend on your board. 5V is 5000 */
void DisplayLED(uint32_t dat)
{
    static uint32_t idx = 0U;
    uint32_t tmp = 0U;
    uint32_t buf[3U] = { 0U, 0U, 0U };

    /* change AD value to real mV */
    tmp = ((dat + 5U) * FULL_MV) / 4095U;
    tmp /= 10U;                 /* we only have 3 7seg LEDs */

    buf[0] = tmp / 100U;
    buf[1] = (tmp / 10U) % 10U;
    buf[2] = tmp % 10U;

    /* we want to display as x.xx V */
    if (idx == 0U) {
        tmp = ledchar_dot[buf[idx]];
    } else {
        tmp = ledchar[buf[idx]];
    }
    SegArrayDisplay(tmp);
    ScanCHx(idx);

    idx++;
    if (idx == 3U) {
        idx = 0U;
    } else {
        /* do nothing */
    }
}



#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
