/**
 *******************************************************************************
 * @file    rmc.c
 * @brief   The driver functions of RMC for the TOSHIBA 'TMPM380' Device Series 
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */
#ifndef __RMC_H
#define __RMC_H
/* Includes ------------------------------------------------------------------*/
#include "main.h"
#include "tx03_common.h"
#include "tmpm380_rmc.h"
/* Private typedef -----------------------------------------------------------*/
typedef enum { RELEASE = 0, PRESS = 1 } RMCPRS;

typedef union tag_IO_SFR32_u {
    uint32_t reg;
    uint8_t byte[4];
} IO_SFR32_u;

/* Private define ------------------------------------------------------------*/
/**************   CHOOSE ONE FORMAT   **************/
/*TOSHIBA format*/
/************** FOR RMC_1 FORMAT ****************/
#define RMC_MAX_CYCLE                   ((uint8_t)0x71)
#define RMC_MIN_CYCLE                   ((uint8_t)0x5A)
#define RMC_MAX_LOW_WIDTH               ((uint8_t)0x4C)
#define RMC_MIN_LOW_WIDTH               ((uint8_t)0x49)

#define RMC_TRG_LOW_WIDTH               ((uint8_t)0xFF)
#define RMC_TRG_MAX_DATA_BIT_CYCLE      ((uint8_t)0xFE)

#define RMC_LARGER_THRESHOLD            ((uint8_t)0x00)
#define RMC_SMALLER_THRESHOLD           ((uint8_t)0x2E)

#define RMC_NOISE_CANCELLATION_TIME     ((uint8_t)0x0D)

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Global variables ----------------------------------------------------------*/
/* external variables --------------------------------------------------------*/
extern WorkState fRMCDone;
extern RMCPRS fRMCPress;
extern uint32_t gRMC_Command;
extern uint16_t gRMC_Address;
extern IO_SFR32_u uRMCBuf;
/* External function prototypes ----------------------------------------------*/
void RMC_GPIOConfig(TSB_RMC_TypeDef * RMCx);
void RMC_ChInit(TSB_RMC_TypeDef * RMCx);
void RMCRcv(void);
/* Private functions ---------------------------------------------------------*/
#endif                          /* __RMC_H */
/*********************************** END OF FILE ******************************/
