/**
 *******************************************************************************
 * @file    main.c
 * @brief   The application functions of IGBT Two PPG for the TOSHIBA 'TMPM380' 
 *          Device Series 
 * @version V0.201
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */
#include "main.h"

WorkState counter_state = BUSY;
Result cancel_result = ERROR;
IGBT_InitTypeDef myIGBT;
#ifdef TSW_CTRL
uint8_t gLastSW1 = 0U;
#endif                          /* TSW_CTRL */

int main(void)
{
    LED_ENABLE;
    LED_4_ON;
    TSW_ENABLE;
#ifdef TSW_CTRL
    gLastSW1 = TSB_PD_DATA_PD0;
#endif                          /* TSW_CTRL */

    myIGBT.StartMode = IGBT_CMD_START;
    myIGBT.OperationMode = IGBT_CONTINUOUS_OUTPUT;
    myIGBT.CntStopState = IGBT_OUTPUT_INACTIVE;
    myIGBT.ActiveAcceptTrg = DISABLE;
    myIGBT.INTPeriod = IGBT_INT_PERIOD_1;
    myIGBT.ClkDiv = IGBT_CLK_DIV_1;
    myIGBT.Output0Init = IGBT_OUTPUT_HIGH_ACTIVE;
    myIGBT.Output1Init = IGBT_OUTPUT_HIGH_ACTIVE;
    myIGBT.TrgDenoiseDiv = IGBT_NO_DENOISE;
    myIGBT.Output0ActiveTiming = 1U;
    myIGBT.Output0InactiveTiming = 1U + IGBT_ACTIVE_PERIOD_20US;
    myIGBT.Output1ActiveTiming = myIGBT.Output0InactiveTiming + IGBT_DEAD_TIME_5US;
    myIGBT.Output1InactiveTiming = myIGBT.Output1ActiveTiming + IGBT_ACTIVE_PERIOD_20US;
    myIGBT.Period = IGBT_PPG_PERIOD_50US;
    myIGBT.EMGFunction = IGBT_EMG_OUTPUT_HIZ;
    myIGBT.EMGDenoiseDiv = IGBT_DENOISE_DIV_16;

    IGBT_IO_Configuration(IGBT0, &myIGBT);

    IGBT_Enable(IGBT0);
    NVIC_EnableIRQ(INTMTEMG0_IRQn);
    do {
        counter_state = IGBT_GetCntState(IGBT0);
    } while (counter_state == BUSY);
    do {
        cancel_result = IGBT_CancelEMGState(IGBT0);
    } while (cancel_result == ERROR);
    LED_4_OFF;
    IGBT_Init(IGBT0, &myIGBT);
#ifndef TSW_CTRL
    IGBT_SetSWRunState(IGBT0, IGBT_RUN);
#else
    if (TSW1_PRESSED) {
        gLastSW1 = 0;
        IGBT_SetSWRunState(IGBT0, IGBT_RUN);
    } else {
        /* Do nothing */
    }
#endif                          /* TSW_CTRL */

    for (;;) {
        if (IGBT0_EMG_STOP) {
            do {
                counter_state = IGBT_GetCntState(IGBT0);
            } while (counter_state == BUSY);
            do {
                cancel_result = IGBT_CancelEMGState(IGBT0);
            } while (cancel_result == ERROR);
            LED_4_OFF;
            IGBT_Init(IGBT0, &myIGBT);
#ifndef TSW_CTRL
            IGBT_SetSWRunState(IGBT0, IGBT_RUN);
#endif                          /* TSW_CTRL */
        } else {
            /* Do nothing */
        }

#ifdef TSW_CTRL
        if (TSW1_PRESSED) {
            if (gLastSW1 == 1) {
                gLastSW1 = 0;
                IGBT_SetSWRunState(IGBT0, IGBT_RUN);
            }
        } else {
            if (gLastSW1 == 0) {
                gLastSW1 = 1;
                IGBT_SetSWRunState(IGBT0, IGBT_STOP);
            }
        }
#endif                          /* TSW_CTRL */
    }
}

void INTMTEMG0_IRQHandler(void)
{
    LED_4_ON;
    IGBT_SetSWRunState(IGBT0, IGBT_STOP);
}

void IGBT_IO_Configuration(TSB_MT_TypeDef * IGBTx, IGBT_InitTypeDef * InitTypeDef)
{
    if (IGBTx == IGBT0) {
        /* Check whether the trigger is used to start */
        if ((InitTypeDef->StartMode != IGBT_CMD_START) ||
            (InitTypeDef->StartMode != IGBT_CMD_START_NO_START_INT)) {
            TSB_PC_IE_PC7IE = 1U;       /* Enable PC7 input */
            TSB_PC_FR2_PC7F2 = 1U;      /* Set PC7 as MT0IN */
        } else {
            TSB_PC_IE_PC7IE = 0U;
            TSB_PC_FR2_PC7F2 = 0U;
        }
        /* Enable ouput0 or not */
        if (InitTypeDef->Output0Init != IGBT_OUTPUT_DISABLE) {
            TSB_PC_CR_PC4C = 1U;        /* Enable PC4 output */
            TSB_PC_FR2_PC4F2 = 1U;      /* Set PC4 as MTOUT00 */
        } else {
            TSB_PC_CR_PC4C = 0U;
            TSB_PC_FR2_PC4F2 = 0U;
        }
        /* Enable ouput1 or not */
        if (InitTypeDef->Output1Init != IGBT_OUTPUT_DISABLE) {
            TSB_PC_CR_PC5C = 1U;        /* Enable PC5 output */
            TSB_PC_FR2_PC5F2 = 1U;      /* Set PC5 as MTOUT10 */
        } else {
            TSB_PC_CR_PC5C = 0U;
            TSB_PC_FR2_PC5F2 = 0U;
        }

        TSB_PC_FR2_PC6F2 = 1U;  /* Set PC6 as GEMG0 */
        TSB_PC_IE_PC6IE = 1U;   /* Enable PC6 input */
    }

#ifdef __TMPM380_H__
    if (IGBTx == IGBT1) {
        /* Check whether the trigger is used to start */
        if ((InitTypeDef->StartMode != IGBT_CMD_START) ||
            (InitTypeDef->StartMode != IGBT_CMD_START_NO_START_INT)) {
            TSB_PG_IE_PG7IE = 1U;       /* Enable PG7 input */
            TSB_PG_FR2_PG7F2 = 1U;      /* Set PG7 as MT1IN */
        } else {
            TSB_PG_IE_PG7IE = 0U;
            TSB_PG_FR2_PG7F2 = 0U;
        }
        /* Enable ouput0 or not */
        if (InitTypeDef->Output0Init != IGBT_OUTPUT_DISABLE) {
            TSB_PG_CR_PG4C = 1U;        /* Enable PG4 output */
            TSB_PG_FR2_PG4F2 = 1U;      /* Set PG4 as MTOUT01 */
        } else {
            TSB_PG_CR_PG4C = 0U;
            TSB_PG_FR2_PG4F2 = 0U;
        }
        /* Enable ouput1 or not */
        if (InitTypeDef->Output1Init != IGBT_OUTPUT_DISABLE) {
            TSB_PG_CR_PG5C = 1U;        /* Enable PG5 output */
            TSB_PG_FR2_PG5F2 = 1U;      /* Set PG5 as MTOUT11 */
        } else {
            TSB_PG_CR_PG5C = 0U;
            TSB_PG_FR2_PG5F2 = 0U;
        }

        TSB_PG_FR2_PG6F2 = 1U;  /* Set PG6 as GEMG1 */
        TSB_PG_IE_PG6IE = 1U;   /* Enable PG6 input */
    }

    if (IGBTx == IGBT2) {
        /* Check whether the trigger is used to start */
        if ((InitTypeDef->StartMode != IGBT_CMD_START) ||
            (InitTypeDef->StartMode != IGBT_CMD_START_NO_START_INT)) {
            TSB_PN_IE_PN7IE = 1U;       /* Enable PN7 input */
            TSB_PN_FR1_PN7F1 = 1U;      /* Set PN7 as MT2IN */
        } else {
            TSB_PN_IE_PN7IE = 0U;
            TSB_PN_FR1_PN7F1 = 0U;
        }
        /* Enable ouput0 or not */
        if (InitTypeDef->Output0Init != IGBT_OUTPUT_DISABLE) {
            TSB_PN_CR_PN4C = 1U;        /* Enable PN4 output */
            TSB_PN_FR1_PN4F1 = 1U;      /* Set PN4 as MTOUT02 */
        } else {
            TSB_PN_CR_PN4C = 0U;
            TSB_PN_FR1_PN4F1 = 0U;
        }
        /* Enable ouput1 or not */
        if (InitTypeDef->Output1Init != IGBT_OUTPUT_DISABLE) {
            TSB_PN_CR_PN5C = 1U;        /* Enable PN5 output */
            TSB_PN_FR1_PN5F1 = 1U;      /* Set PN5 as MTOUT12 */
        } else {
            TSB_PN_CR_PN5C = 0U;
            TSB_PN_FR1_PN5F1 = 0U;
        }

        TSB_PN_FR1_PN6F1 = 1U;  /* Set PN6 as GEMG2 */
        TSB_PN_IE_PN6IE = 1U;   /* Enable PN6 input */
    }
#endif                          /* __TMPM380_H__ */
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif                          /* DEBUG */
