/**
 *******************************************************************************
 * @file    rtc.c
 * @brief   The application functions of RTC_Basic demo for the
 *          TOSHIBA 'TMPM380' Device Series 
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"
#include "led.h"

/**
  * @brief  Initialize RTC register and variables
  * @param  None
  * @retval None
  */

void RTC_Init(void)
{
    RTC_DateTypeDef Date_Struct;
    RTC_TimeTypeDef Time_Struct;

    Date_Struct.LeapYear = RTC_LEAP_YEAR_2;
    Date_Struct.Year = (uint8_t) 10U;
    Date_Struct.Month = (uint8_t) 10U;
    Date_Struct.Date = (uint8_t) 22U;
    Date_Struct.Day = RTC_FRI;

    Time_Struct.HourMode = RTC_24_HOUR_MODE;
    Time_Struct.Hour = (uint8_t) 12U;
    Time_Struct.Min = (uint8_t) 50U;
    Time_Struct.Sec = (uint8_t) 55U;

    RTC_DisableClock();
    RTC_DisableAlarm();

    /* Reset RTC sec counter */
    RTC_ResetClockSec();
    /* Enable 1Hz interrupt */
    RTC_SetAlarmOutput(RTC_PULSE_1_HZ);
    /* Enable RTCINT */
    RTC_SetRTCINT(ENABLE);
    /* Set RTC Time value */
    RTC_SetTimeValue(&Time_Struct);
    /* Set RTC Date value */
    RTC_SetDateValue(&Date_Struct);
}


void RTCDisplaySec(void)
{
    uint8_t Sec;
    uint8_t tmp;
    Sec = RTC_GetSec();
    tmp = Sec % 10U;

    SegArrayDisplay(ledchar[tmp]);

}
