/** 
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of TMRB_PPG demo for the TOSHIBA
 *          'TMPM380' Device Series 
 * @version V0.102
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"

/* declaration ---------------------------------------------------------------*/
void SegDisplay(uint8_t leadingtiming);
void delay(uint32_t time);

/**
  * @brief  delay some time
  * @param  delay time
  * @retval None.
  */
void delay(uint32_t time)
{
    uint32_t i = 0U;
    for (i = 0U; i < time; i++) {
        /* Do nothing */
    }
}

/**
  * @brief  The main function of TMRB_PPG demo
  * @param  None
  * @retval None
  */
int main(void)
{
    uint8_t Rate = 0U;
    uint32_t LeadingTiming[5] = { 0x8CAU, 0x753U, 0x4E2U, 0x271U, 0xFAU };       /* leadingtiming: 10%, 25%, 50%, 75%, 90% */
    uint8_t leadingtiming_num[5] = { 10U, 25U, 50U, 75U, 90U };  /* leadingtiming number for LED display */
    uint8_t keyvalue;

    TMRB_InitTypeDef m_tmrb;
    TMRB_FFOutputTypeDef PPGFFInital;

    GPIO_SetInput(KEYPORT, GPIO_BIT_0); /* set KEY port to input */

    LEDInit();                  /* LED initialization */
    LedDisable(LED_CH1 | LED_CH2 | LED_CH3 | LED_CH4);  /* Turn off all LED channel */

    /* Set PF1 as TB7OUT for PPG output */
    GPIO_SetOutput(GPIO_PF, GPIO_BIT_1);
    GPIO_EnableFuncReg(GPIO_PF, GPIO_FUNC_REG_1, GPIO_BIT_1);
    GPIO_SetPullUp(GPIO_PF, GPIO_BIT_1, ENABLE);

    m_tmrb.Mode = TMRB_INTERVAL_TIMER;
    m_tmrb.ClkDiv = TMRB_CLK_DIV_8;
    m_tmrb.UpCntCtrl = TMRB_AUTO_CLEAR;
    m_tmrb.TrailingTiming = TMRB7TIME;   /* T = 500us */
    m_tmrb.LeadingTiming = LeadingTiming[Rate];
    PPGFFInital.FlipflopCtrl = TMRB_FLIPFLOP_CLEAR;
    PPGFFInital.FlipflopReverseTrg = TMRB_FLIPFLOP_MATCH_TRAILINGTIMING | TMRB_FLIPFLOP_MATCH_LEADINGTIMING;

    TMRB_Enable(TSB_TB7);
    TMRB_Init(TSB_TB7, &m_tmrb);
    TMRB_SetFlipFlop(TSB_TB7, &PPGFFInital);
    TMRB_SetDoubleBuf(TSB_TB7, ENABLE, TMRB_WRITE_REG_SEPARATE);        /* enable double buffer */
    TMRB_SetRunState(TSB_TB7, TMRB_RUN);

    do {                        /* wait if switch is High */
        keyvalue = GPIO_ReadDataBit(KEYPORT, GPIO_BIT_0);
        SegDisplay(leadingtiming_num[0]);
    } while (GPIO_BIT_VALUE_1 == keyvalue);

    delay(0xFFFU);              /* noise cancel */
    LedDisable(LED_CH1 | LED_CH2 | LED_CH3 | LED_CH4);  /* diable all LED channel */

    while (1) {
        do {                    /* wait if switch is Low */
            keyvalue = GPIO_ReadDataBit(KEYPORT, GPIO_BIT_0);
            SegDisplay(leadingtiming_num[Rate]); /* display current leadingtiming */
        } while (GPIO_BIT_VALUE_0 == keyvalue);

        delay(0xFFFU);          /* noise cancel */

        Rate++;
        if (Rate >= LEADINGTIMINGMAX) {  /* change leadingtiming rate */
            Rate = LEADINGTIMINGINIT;
        } else {
            /* Do nothing */
        }

        TMRB_ChangeLeadingTiming(TSB_TB7, LeadingTiming[Rate]);   /* switch is High again */

        do {                    /* wait if switch is High */
            keyvalue = GPIO_ReadDataBit(KEYPORT, GPIO_BIT_0);
            SegDisplay(leadingtiming_num[Rate]); /* display current leadingtiming */
        } while (GPIO_BIT_VALUE_1 == keyvalue);

        delay(0xFFFU);          /* noise cancel */
        LedDisable(LED_CH1 | LED_CH2 | LED_CH3 | LED_CH4);      /* diable all LED channel */
    }
}

/**
  * @brief  display the leadingtiming on 7-segs LED
  * @param  leadingtiming value
  * @retval None
  */
void SegDisplay(uint8_t leadingtiming)
{
    switch (leadingtiming) {
    case 10U:                  /* leadingtiming = 10% */
        LedDisable(LED_CH3);
        SegArrayDisplay(chSpace);
        LedEnable(LED_CH2);
        SegArrayDisplay(ch1);
        delay(0xFFFU);
        LedDisable(LED_CH2);    /* change display channel */
        SegArrayDisplay(chSpace);
        LedEnable(LED_CH3);
        SegArrayDisplay(ch0);
        delay(0xFFFU);
        break;
    case 25U:                  /* leadingtiming = 25% */
        LedDisable(LED_CH3);
        SegArrayDisplay(chSpace);
        LedEnable(LED_CH2);
        SegArrayDisplay(ch2);
        delay(0xFFFU);
        LedDisable(LED_CH2);    /* change display channel */
        SegArrayDisplay(chSpace);
        LedEnable(LED_CH3);
        SegArrayDisplay(ch5);
        delay(0xFFFU);
        break;
    case 50U:                  /* leadingtiming = 50% */
        LedDisable(LED_CH3);
        SegArrayDisplay(chSpace);
        LedEnable(LED_CH2);
        SegArrayDisplay(ch5);
        delay(0xFFFU);
        LedDisable(LED_CH2);    /* change display channel */
        SegArrayDisplay(chSpace);
        LedEnable(LED_CH3);
        SegArrayDisplay(ch0);
        delay(0xFFFU);
        break;
    case 75U:                  /* leadingtiming = 75% */
        LedDisable(LED_CH3);
        SegArrayDisplay(chSpace);
        LedEnable(LED_CH2);
        SegArrayDisplay(ch7);
        delay(0xFFFU);
        LedDisable(LED_CH2);    /* change display channel */
        SegArrayDisplay(chSpace);
        LedEnable(LED_CH3);
        SegArrayDisplay(ch5);
        delay(0xFFFU);
        break;
    case 90U:                  /* leadingtiming = 90% */
        LedDisable(LED_CH3);
        SegArrayDisplay(chSpace);
        LedEnable(LED_CH2);
        SegArrayDisplay(ch9);
        delay(0xFFFU);
        LedDisable(LED_CH2);    /* change display channel */
        SegArrayDisplay(chSpace);
        LedEnable(LED_CH3);
        SegArrayDisplay(ch0);
        delay(0xFFFU);
        break;
    default:
        /* Do nothing */
        break;
    }
}

/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */
#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
