/**
 ******************************************************************************
 * @file     led.c
 * @brief    LED driver for the TOSHIBA 'TMPM380' Device Series
 * @version  V0.101
 * @date     2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 ******************************************************************************
 */

/** include files **/

#include "led.h"
#include "tmpm380_gpio.h"
/** local definitions **/

/** default settings **/

/** external functions **/

/** external data **/

/** internal functions **/

/** public data **/
char ledchar[16U] = {
ch0, ch1, ch2, ch3, ch4, ch5, ch6, ch7, ch8, ch9, chA, chb, chC, chd, chE, chF
};

char ledchar_dot[10U] = {
ch0dot, ch1dot, ch2dot, ch3dot, ch4dot, ch5dot, ch6dot, ch7dot, ch8dot, ch9dot 
};

/** private data **/

/** public functions **/
/*************************************************************************
 * Function Name: LED_Init
 * Parameters:None
 *
 * Return:None  
 *
 * Description: Init LED ports
 *
 *************************************************************************/
void LEDInit(void)
{
    uint8_t reg;
   /*switch all leds off but the enabled*/
    GPIO_SetOutput(LED_CH_PORT,0XF0U);
    reg = GPIO_ReadData(LED_CH_PORT);
    reg &= 0x0Fu;
    GPIO_WriteData(LED_CH_PORT,reg); 
    
    GPIO_SetOutput(LED_DATA_PORT,0XFFU);    
    GPIO_WriteData(LED_DATA_PORT,0XFFU); 
    
}
/*************************************************************************
 * Function Name: LedOff
 * Parameters:LED number
 *
 * Return:None  
 *
 * Description: Led Digtit OFF, but others don't change
 *
 *************************************************************************/
void LedOff(uint8_t led)
{
    uint8_t reg;
    reg = GPIO_ReadData(LED_DATA_PORT);
    reg |= led;
    GPIO_WriteData(LED_DATA_PORT,reg);
}

/*************************************************************************
 * Function Name: LedOn
 * Parameters:LED number
 *
 * Return:None  
 *
 * Description: Led Digtit ON, but others don't change
 *
 *************************************************************************/
void LedOn(uint8_t led)
{
  GPIO_WriteData(LED_DATA_PORT,(~led));
}

/*************************************************************************
 * Function Name: LedDisable
 * Parameters:disable channel number
 *
 * Return:None  
 *
 * Description: disable channel n display 
 *
 *************************************************************************/
void LedDisable(uint8_t n)
{
    uint8_t tmp;
    tmp = GPIO_ReadData(LED_CH_PORT); 
    tmp |= n;
    GPIO_WriteData(LED_CH_PORT,tmp); 
}
/*************************************************************************
 * Function Name: LedEnable
 * Parameters:Enable channel number
 *
 * Return:None  
 *
 * Description: Enable channel n display 
 *
 *************************************************************************/
void LedEnable(uint8_t n)
{
    uint8_t tmp;
    tmp = GPIO_ReadData(LED_CH_PORT); 
    n = ~n;
    tmp &= n;
   
    GPIO_WriteData(LED_CH_PORT,tmp); 
}

/*************************************************************************
 * Function Name: SegArrayDisplay
 * Parameters:seg char 
 *
 * Return:None  
 *
 * Description: Seg display char
 *
 *************************************************************************/
void SegArrayDisplay(uint8_t SegChar)
{
  GPIO_WriteData(LED_DATA_PORT,SegChar);
}


/*************************************************************************
 * Function Name: ScanCHx
 * Parameters: ch , which can be 0,1,2,3
 * Return:None  
 * Description: to enable channel 'ch' of LEDs on M380-SK board.
 *              order of 7seg LED: left to right: 0,1,2. 
 *              the 8 independent LED is ch 3 
 *************************************************************************/
void ScanCHx(uint32_t ch)
{
    static uint8_t scan[4U] = { 0x70U, 0xB0U, 0xD0U, 0xE0U };
    uint8_t tmp;
    
    tmp = GPIO_ReadData(LED_CH_PORT); 
    tmp &= 0x0FU;
    tmp |= scan[ch];
   
    GPIO_WriteData(LED_CH_PORT,tmp);   
}
