/**
 ******************************************************************************
 * @file     led.h
 * @brief    LED driver for the TOSHIBA 'TMPM380' Device Series
 * @version  V0.101
 * @date     2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 ******************************************************************************
 */
#ifndef __LED_H
#define __LED_H
/** include files **/
#include "TMPM380.h"
#include "tmpm380_gpio.h"

/** definitions **/

/*Seven segment LED definitions*/
#define segA  (1U<<0U)
#define segB  (1U<<1U)
#define segC  (1U<<2U)
#define segD  (1U<<3U)
#define segE  (1U<<4U)
#define segF  (1U<<5U)
#define segG  (1U<<6U)
#define segDP (1U<<7U)

/*Seven segnent LED char codes*/
#define ch0   (uint8_t)(~(segA | segB | segC | segD | segE | segF       ))
#define ch1   (uint8_t)(~(       segB | segC                            ))
#define ch2   (uint8_t)(~(segA | segB        | segD | segE        | segG))
#define ch3   (uint8_t)(~(segA | segB | segC | segD               | segG))
#define ch4   (uint8_t)(~(       segB | segC               | segF | segG))
#define ch5   (uint8_t)(~(segA        | segC | segD        | segF | segG))
#define ch6   (uint8_t)(~(segA        | segC | segD | segE | segF | segG))
#define ch7   (uint8_t)(~(segA | segB | segC                            ))
#define ch8   (uint8_t)(~(segA | segB | segC | segD | segE | segF | segG))
#define ch9   (uint8_t)(~(segA | segB | segC | segD        | segF | segG))
#define chA   (uint8_t)(~(segA | segB | segC        | segE | segF | segG))
#define chb   (uint8_t)(~(              segC | segD | segE | segF | segG))
#define chC   (uint8_t)(~(segA               | segD | segE | segF       ))
#define chd   (uint8_t)(~(       segB | segC | segD | segE        | segG))
#define chE   (uint8_t)(~(segA               | segD | segE | segF | segG))
#define chF   (uint8_t)(~(segA                      | segE | segF | segG))
#define chDot (uint8_t)(~segDP)
#define chSpace 0xFFU

/*Seven segnent LED char with dot codes*/
#define ch0dot    (uint8_t)(~(~ch0 | segDP))
#define ch1dot    (uint8_t)(~(~ch1 | segDP))
#define ch2dot    (uint8_t)(~(~ch2 | segDP))
#define ch3dot    (uint8_t)(~(~ch3 | segDP))
#define ch4dot    (uint8_t)(~(~ch4 | segDP))
#define ch5dot    (uint8_t)(~(~ch5 | segDP))
#define ch6dot    (uint8_t)(~(~ch6 | segDP))
#define ch7dot    (uint8_t)(~(~ch7 | segDP))
#define ch8dot    (uint8_t)(~(~ch8 | segDP))
#define ch9dot    (uint8_t)(~(~ch9 | segDP))



/*LEDs difinitions*/
#define LED4  (1U<<0U)
#define LED5  (1U<<4U)
#define LED6  (1U<<1U)
#define LED7  (1U<<5U)
#define LED8  (1U<<2U)
#define LED9  (1U<<6U)
#define LED10 (1U<<3U)
#define LED11 (1U<<7U)

#define LED_CH1    0X80U    /*Left SEG*/
#define LED_CH2    0X40U    
#define LED_CH3    0X20U    
#define LED_CH4    0X10U    /*LED*/

#define LED_CH_PORT     GPIO_PG     
#define LED_DATA_PORT   GPIO_PA

/** public data **/
/*seven segment led code table*/
extern char ledchar[16U];
extern char ledchar_dot[10U];

/** public functions **/
/*************************************************************************
 * Function Name: LED_Init
 * Parameters:None
 *
 * Return:None  
 *
 * Description: Init LED ports
 *
 *************************************************************************/
void LEDInit(void);

/*************************************************************************
 * Function Name: LedDisable
 * Parameters:disable channel number
 *
 * Return:None  
 *
 * Description: disable channel n display
 *
 *************************************************************************/
void LedDisable(uint8_t n);

/*************************************************************************
 * Function Name: LedDisable
 * Parameters:Enable channel number
 *
 * Return:None  
 *
 * Description: Enable channel n display
 *
 *************************************************************************/
void LedEnable(uint8_t n);

/*************************************************************************
 * Function Name: LedOff
 * Parameters:LED number
 *
 * Return:None  
 *
 * Description: Led Digtit OFF, but others don't change
 *
 *************************************************************************/
void LedOff(uint8_t led);

/*************************************************************************
 * Function Name: LedOn
 * Parameters:LED number
 *
 * Return:None  
 *
 * Description: Led Digtit ON, but others don't change
 *
 *************************************************************************/
void LedOn(uint8_t led);

/*************************************************************************
 * Function Name: SegArrayDisplay
 * Parameters:seg char 
 *
 * Return:None  
 *
 * Description: Seg display char
 *
 *************************************************************************/
void SegArrayDisplay(uint8_t SegChar);


/*************************************************************************
 * Function Name: ScanCHx
 * Parameters: ch , which can be 0,1,2,3
 * Return:None  
 * Description: to enable channel 'ch' of LEDs on M380-SK board.
 *              order of 7seg LED: left to right: 0,1,2. 
 *              the 8 independent LED is ch 3 
 *************************************************************************/
void ScanCHx(uint32_t ch);

#endif  /* __LED_H */
